==> zio-aws-ssm_2.13-5.17.158.3-sources.jar: zio/aws/ssm/model/ResumeSessionResponse.scala <==
package zio.aws.ssm.model
import zio.aws.ssm.model.primitives.{StreamUrl, TokenValue, SessionId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class ResumeSessionResponse(
    sessionId: Option[SessionId] = None,
    tokenValue: Option[TokenValue] = None,
    streamUrl: Option[StreamUrl] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssm.model.ResumeSessionResponse = {
    import ResumeSessionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssm.model.ResumeSessionResponse
      .builder()
      .optionallyWith(
        sessionId.map(value => SessionId.unwrap(value): java.lang.String)
      )(_.sessionId)
      .optionallyWith(
        tokenValue.map(value => TokenValue.unwrap(value): java.lang.String)
      )(_.tokenValue)
      .optionallyWith(
        streamUrl.map(value => StreamUrl.unwrap(value): java.lang.String)
      )(_.streamUrl)
      .build()
  }
  def asReadOnly: zio.aws.ssm.model.ResumeSessionResponse.ReadOnly =
    zio.aws.ssm.model.ResumeSessionResponse.wrap(buildAwsValue())
}
object ResumeSessionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssm.model.ResumeSessionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssm.model.ResumeSessionResponse =
      zio.aws.ssm.model.ResumeSessionResponse(
        sessionId.map(value => value),
        tokenValue.map(value => value),
        streamUrl.map(value => value)
      )
    def sessionId: Option[SessionId]
    def tokenValue: Option[TokenValue]
    def streamUrl: Option[StreamUrl]
    def getSessionId: ZIO[Any, AwsError, SessionId] =
      AwsError.unwrapOptionField("sessionId", sessionId)
    def getTokenValue: ZIO[Any, AwsError, TokenValue] =
      AwsError.unwrapOptionField("tokenValue", tokenValue)
    def getStreamUrl: ZIO[Any, AwsError, StreamUrl] =
      AwsError.unwrapOptionField("streamUrl", streamUrl)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssm.model.ResumeSessionResponse
  ) extends zio.aws.ssm.model.ResumeSessionResponse.ReadOnly {
    override val sessionId: Option[SessionId] = scala
      .Option(impl.sessionId())
      .map(value => zio.aws.ssm.model.primitives.SessionId(value))
    override val tokenValue: Option[TokenValue] = scala
      .Option(impl.tokenValue())
      .map(value => zio.aws.ssm.model.primitives.TokenValue(value))
    override val streamUrl: Option[StreamUrl] = scala
      .Option(impl.streamUrl())
      .map(value => zio.aws.ssm.model.primitives.StreamUrl(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssm.model.ResumeSessionResponse
  ): zio.aws.ssm.model.ResumeSessionResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-ssm_2.13-6.20.103.1-sources.jar: zio/aws/ssm/model/ResumeSessionResponse.scala <==
package zio.aws.ssm.model
import zio.aws.ssm.model.primitives.{StreamUrl, TokenValue, SessionId}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ResumeSessionResponse(
    sessionId: Optional[SessionId] = Optional.Absent,
    tokenValue: Optional[TokenValue] = Optional.Absent,
    streamUrl: Optional[StreamUrl] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.ssm.model.ResumeSessionResponse = {
    import ResumeSessionResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.ssm.model.ResumeSessionResponse
      .builder()
      .optionallyWith(
        sessionId.map(value => SessionId.unwrap(value): java.lang.String)
      )(_.sessionId)
      .optionallyWith(
        tokenValue.map(value => TokenValue.unwrap(value): java.lang.String)
      )(_.tokenValue)
      .optionallyWith(
        streamUrl.map(value => StreamUrl.unwrap(value): java.lang.String)
      )(_.streamUrl)
      .build()
  }
  def asReadOnly: zio.aws.ssm.model.ResumeSessionResponse.ReadOnly =
    zio.aws.ssm.model.ResumeSessionResponse.wrap(buildAwsValue())
}
object ResumeSessionResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.ssm.model.ResumeSessionResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.ssm.model.ResumeSessionResponse =
      zio.aws.ssm.model.ResumeSessionResponse(
        sessionId.map(value => value),
        tokenValue.map(value => value),
        streamUrl.map(value => value)
      )
    def sessionId: Optional[SessionId]
    def tokenValue: Optional[TokenValue]
    def streamUrl: Optional[StreamUrl]
    def getSessionId: ZIO[Any, AwsError, SessionId] =
      AwsError.unwrapOptionField("sessionId", sessionId)
    def getTokenValue: ZIO[Any, AwsError, TokenValue] =
      AwsError.unwrapOptionField("tokenValue", tokenValue)
    def getStreamUrl: ZIO[Any, AwsError, StreamUrl] =
      AwsError.unwrapOptionField("streamUrl", streamUrl)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.ssm.model.ResumeSessionResponse
  ) extends zio.aws.ssm.model.ResumeSessionResponse.ReadOnly {
    override val sessionId: Optional[SessionId] = zio.aws.core.internal
      .optionalFromNullable(impl.sessionId())
      .map(value => zio.aws.ssm.model.primitives.SessionId(value))
    override val tokenValue: Optional[TokenValue] = zio.aws.core.internal
      .optionalFromNullable(impl.tokenValue())
      .map(value => zio.aws.ssm.model.primitives.TokenValue(value))
    override val streamUrl: Optional[StreamUrl] = zio.aws.core.internal
      .optionalFromNullable(impl.streamUrl())
      .map(value => zio.aws.ssm.model.primitives.StreamUrl(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.ssm.model.ResumeSessionResponse
  ): zio.aws.ssm.model.ResumeSessionResponse.ReadOnly = new Wrapper(impl)
}
